@@ -3,11 +3,73 @@ import pregex.pre as _pre
 import pregex.exceptions as _ex
 
 
+__doc__ = """
+This module contains all necessary classes that are used to construct both capturing
+and non-capturing groups, as well as any other class that relates to group-related
+concepts, such as backreferences and conditionals. In general, one should not have
+to concern themselves with pattern-grouping, as patterns are automatically grouped
+into non-capturing groups whenever this is deemed necessary. Consider for instance
+the following code snippet:
+
+.. code-block:: python
+
+   from pregex.quantifiers import Optional
+
+   print(Optional("a").get_pattern()) # This prints "a?"
+   print(Optional("aa").get_pattern()) # This prints "(?:aa)?"
+
+In the first case, quantifier :class:`~pregex.quantifiers.Optional` is applied to the pattern
+directly, whereas in the second case the pattern is wrapped within a non-capturing group
+so that "aa" is quantified as a whole. Even so, one can also explicitly construct a
+non-capturing group out of any pattern if one wishes to do so:
+
+.. code-block:: python
+
+   from pregex.groups import Group
+   from pregex.quantifiers import Optional
+
+   print(Group(Optional("a")).get_pattern()) # This prints "(?:a)?"
+
+Capturing patterns
+===========================================
+
+You'll find however that :class:`Capture` is probably the most important class
+of this module, as it is used to create a capturing group out of a pattern,
+so that said pattern is also captured separately whenever a match occurs.
+
+.. code-block:: python
+
+   from pregex.groups import Capture
+   from pregex.classes import AnyLetter
+
+   pre = AnyLetter() + Capture(AnyLetter()) + AnyLetter()
+
+   print(pre.get_captures("abc def")) # This prints "[('b'), ('e')]"
+
+Classes & methods
+===========================================
+
+Below are listed all classes within :py:mod:`pregex.groups`
+along with any possible methods they may possess.
+"""
+
+
 class __Group(_pre.Pregex):
     '''
-    Constitutes the base class for classes "Capture" and "Group".
+    Constitutes the base class for all classes that are part of this module.
+
+    :param Pregex | str pre: A Pregex instance or string representing the pattern \
+        that is to be groupped.
+    :param (Pregex => str) transform: A `transform` function for the provided pattern.
     '''
     def __init__(self, pre: _pre.Pregex or str, transform) -> _pre.Pregex:
+        '''
+        Constitutes the base class for all classes that are part of this module.
+
+        :param Pregex | str pre: A Pregex instance or string representing the pattern \
+            that is to be groupped.
+        :param (Pregex => str) transform: A `transform` function for the provided pattern.
+        '''
         pattern = transform(__class__._to_pregex(pre))
         super().__init__(pattern, escape=False)
 
@@ -18,10 +80,10 @@ class Capture(__Group):
 
     :param Pregex | str pre: The pattern out of which the capturing group is created.
     :param str name: The name that is assigned to the captured group for backreference purposes. \
-        A value of "''" indicates that no name is to be assigned to the group. Defaults to "''".
+        A value of ``''`` indicates that no name is to be assigned to the group. Defaults to ``''``.
 
-    :raises NonStringArgumentException: Parameter 'name' is not a string.
-    :raises InvalidCapturingGroupNameException: Parameter 'name' is not a valid \
+    :raises NonStringArgumentException: Parameter ``name`` is not a string.
+    :raises InvalidCapturingGroupNameException: Parameter ``name`` is not a valid \
         capturing-group name. Such name must contain word characters only and start \
         with a non-digit character.
 
@@ -38,10 +100,10 @@ class Capture(__Group):
 
         :param Pregex | str pre: The pattern out of which the capturing group is created.
         :param str name: The name that is assigned to the captured group for backreference purposes. \
-            A value of "''" indicates that no name is to be assigned to the group. Defaults to "''".
+            A value of ``''`` indicates that no name is to be assigned to the group. Defaults to ``''``.
 
-        :raises NonStringArgumentException: Parameter 'name' is not a string.
-        :raises InvalidCapturingGroupNameException: Parameter 'name' is not a valid \
+        :raises NonStringArgumentException: Parameter ``name`` is not a string.
+        :raises InvalidCapturingGroupNameException: Parameter ``name`` is not a valid \
             capturing-group name. Such name must contain word characters only and start \
             with a non-digit character.
 
@@ -91,8 +153,8 @@ class Backreference(__Group):
 
     :param str name: The name of the referenced capturing group.
 
-    :raises NonStringArgumentException: Parameter 'name' is not a string.
-    :raises InvalidCapturingGroupNameException: Parameter 'name' is not a valid \
+    :raises NonStringArgumentException: Parameter ``name`` is not a string.
+    :raises InvalidCapturingGroupNameException: Parameter ``name`` is not a valid \
         capturing-group name. Such name must contain word characters only and start \
         with a non-digit character.
     '''
@@ -105,8 +167,8 @@ class Backreference(__Group):
 
         :param str name: The name of the referenced capturing group.
 
-        :raises NonStringArgumentException: Parameter 'name' is not a string.
-        :raises InvalidCapturingGroupNameException: Parameter 'name' is not a valid \
+        :raises NonStringArgumentException: Parameter ``name`` is not a string.
+        :raises InvalidCapturingGroupNameException: Parameter ``name`` is not a valid \
             capturing-group name. Such name must contain word characters only and start \
             with a non-digit character.
         '''
@@ -119,36 +181,36 @@ class Backreference(__Group):
     
 class Conditional(__Group):
     '''
-    Given the name of a capturing group, matches 'pre1' only if said capturing group has \
-    been previously matched. Furthermore, if a second pattern 'pre2' is provided, then this \
+    Given the name of a capturing group, matches ``pre1`` only if said capturing group has \
+    been previously matched. Furthermore, if a second pattern ``pre2`` is provided, then this \
     pattern is matched in case the referenced capturing group was not matched, though one \
     should be aware that for this to be possible, the referenced capturing group must be optional.
 
     :param str name: The name of the referenced capturing group.
     :param Pregex | str pre1: The pattern that is to be matched in case condition is true.
     :param Pregex | str pre2: The pattern that is to be matched in case condition is false. \
-        Defaults to "''".
+        Defaults to ``''``.
 
-    :raises NonStringArgumentException: Parameter 'name' is not a string.
-    :raises InvalidCapturingGroupNameException: Parameter 'name' is not a valid \
+    :raises NonStringArgumentException: Parameter ``name`` is not a string.
+    :raises InvalidCapturingGroupNameException: Parameter ``name`` is not a valid \
         capturing-group name. Such name must contain word characters only and start \
         with a non-digit character.
     '''
 
     def __init__(self, name: str, pre1: _pre.Pregex or str, pre2: _pre.Pregex or str = ''):
         '''
-        Given the name of a capturing group, matches 'pre1' only if said capturing group has\
-        been previously matched. Furthermore, if a second pattern 'pre2' is provided, then this \
+        Given the name of a capturing group, matches ``pre1`` only if said capturing group has \
+        been previously matched. Furthermore, if a second pattern ``pre2`` is provided, then this \
         pattern is matched in case the referenced capturing group was not matched, though one \
         should be aware that for this to be possible, the referenced capturing group must be optional.
 
         :param str name: The name of the referenced capturing group.
         :param Pregex | str pre1: The pattern that is to be matched in case condition is true.
         :param Pregex | str pre2: The pattern that is to be matched in case condition is false. \
-            Defaults to "''".
+            Defaults to ``''``.
 
-        :raises NonStringArgumentException: Parameter 'name' is not a string.
-        :raises InvalidCapturingGroupNameException: Parameter 'name' is not a valid \
+        :raises NonStringArgumentException: Parameter ``name`` is not a string.
+        :raises InvalidCapturingGroupNameException: Parameter ``name`` is not a valid \
             capturing-group name. Such name must contain word characters only and start \
             with a non-digit character.
         '''
